@@ -9,7 +9,7 @@ from trimmer.trim_source import trim_from_source
 
 def test_trim_from_url():
     # workaround for travis + python stdout opened in rb+ mode
-    sys.stdout = open(sys.stdout.fileno(), mode='r+', encoding='utf8', buffering=1)
+    # sys.stdout = open(sys.stdout.fileno(), mode='r+', encoding='utf8', buffering=1)
 
     url = 'https://www.youtube.com/watch?v=omafc3SazWA'
     trim_from_source(url, artist='Stachu Jones', title='O kurna',
