@@ -1,8 +1,6 @@
 import re
 from typing import Tuple
 
-from trimmer.sublog.sublog import info
-
 
 def extract_artist_title(name: str) -> Tuple[str, str]:
     if '-' not in name:
@@ -12,8 +10,8 @@ def extract_artist_title(name: str) -> Tuple[str, str]:
     artist = name[:dash_index].strip()
 
     title = name[dash_index + 1:].strip()
-    title = re.sub(r"\(.+?\)", "", title)
-    title = re.sub(r"[. ]+$", "", title)
+    title = re.sub(r"\(.+?\)", "", title)  # parentheses
+    title = re.sub(r"\[.+?\]", "", title)  # square brackets
+    title = re.sub(r"[. ]+$", "", title.strip())
 
-    info('artist & title extracted from youtube page', artist=artist, title=title)
     return artist, title
